'use strict';

function readSharedLangGraphAgentConfig(rootConfig) {
  const config = rootConfig.getOptionalConfig("genai.langgraph");
  let langfuseAgentConfig;
  if (config) {
    const langfuseConfig = config.getOptionalConfig("langfuse");
    if (langfuseConfig) {
      langfuseAgentConfig = {
        baseUrl: langfuseConfig.getString("baseUrl"),
        publicKey: langfuseConfig.getString("publicKey"),
        secretKey: langfuseConfig.getString("secretKey"),
        flushAt: langfuseConfig.getOptionalNumber("flushAt")
      };
    }
  }
  return {
    langfuse: langfuseAgentConfig
  };
}
function readLangGraphAgentConfig(agentConfig) {
  const config = agentConfig.getConfig("langgraph");
  return {
    messagesMaxTokens: config.getNumber("messagesMaxTokens"),
    maxTokens: config.getOptionalNumber("maxTokens"),
    temperature: config.getOptionalNumber("temperature"),
    topP: config.getOptionalNumber("topP"),
    bedrock: readLangGraphAgentBedrockConfig(config),
    openai: readLangGraphAgentOpenAIConfig(config)
  };
}
function readLangGraphAgentBedrockConfig(agentConfig) {
  if (!agentConfig.has("bedrock")) {
    return void 0;
  }
  const config = agentConfig.getConfig("bedrock");
  return {
    modelId: config.getString("modelId"),
    region: config.getString("region")
  };
}
function readLangGraphAgentOpenAIConfig(agentConfig) {
  if (!agentConfig.has("openai")) {
    return void 0;
  }
  const config = agentConfig.getConfig("openai");
  return {
    apiKey: config.getString("apiKey"),
    modelName: config.getOptionalString("modelName"),
    baseUrl: config.getOptionalString("baseUrl")
  };
}

exports.readLangGraphAgentBedrockConfig = readLangGraphAgentBedrockConfig;
exports.readLangGraphAgentConfig = readLangGraphAgentConfig;
exports.readLangGraphAgentOpenAIConfig = readLangGraphAgentOpenAIConfig;
exports.readSharedLangGraphAgentConfig = readSharedLangGraphAgentConfig;
//# sourceMappingURL=config.cjs.js.map
