'use strict';

class ResponseTransformStream extends TransformStream {
  constructor(sessionId) {
    super({
      start: (controller) => {
        controller.enqueue({
          type: "ResponseEvent",
          sessionId
        });
      },
      transform: (chunk, controller) => this.transform(chunk, controller),
      flush: (controller) => this.flush(controller)
    });
  }
  transform(chunk, controller) {
    const event = chunk.event;
    const data = chunk.data;
    if (event === "on_chat_model_stream") {
      const msg = data.chunk;
      if (!msg.tool_call_chunks?.length) {
        const content = msg.content;
        controller.enqueue({
          type: "ChunkEvent",
          token: content.toString()
        });
      }
    } else if (event === "on_tool_start") {
      const msg = data;
      controller.enqueue({
        type: "ToolEvent",
        name: chunk.name,
        input: msg.input.input
      });
    }
  }
  flush(controller) {
    controller.terminate();
  }
}

exports.ResponseTransformStream = ResponseTransformStream;
//# sourceMappingURL=transform.cjs.js.map
